Index: src/x64/macro-assembler-x64.h |
diff --git a/src/x64/macro-assembler-x64.h b/src/x64/macro-assembler-x64.h |
index 5d66c6ec1e228891db7f9cef0e293977d34091ad..c0eda82380ca6c805933d1825e09601b0ec8c190 100644 |
--- a/src/x64/macro-assembler-x64.h |
+++ b/src/x64/macro-assembler-x64.h |
@@ -1473,12 +1473,11 @@ class MacroAssembler: public Assembler { |
int min_length = 0, |
Register scratch = kScratchRegister); |
- // Initialize fields with filler values. Fields starting at |start_offset| |
- // not including end_offset are overwritten with the value in |filler|. At |
- // the end the loop, |start_offset| takes the value of |end_offset|. |
- void InitializeFieldsWithFiller(Register start_offset, |
- Register end_offset, |
- Register filler); |
+ // Initialize fields with filler values. Fields starting at |current_address| |
+ // not including |end_address| are overwritten with the value in |filler|. At |
+ // the end the loop, |current_address| takes the value of |end_address|. |
+ void InitializeFieldsWithFiller(Register current_address, |
+ Register end_address, Register filler); |
// Emit code for a truncating division by a constant. The dividend register is |